"""
Tests for ingest_envoy.collectors
"""
from unittest.mock import patch

from ingest_envoy.collectors import ImageCollector
from ingest_envoy.schema import AbstractTextFile

parameters = {
    "sdmId": "brain_000.58099.67095825232",
    "telescope": "EVLA",
    "workflowName": "std_cms_imaging",
    "workflowRequestId": "12",
    "spl": "uid://evla/execblock/ec082e65-452d-4fec-ad88-f5b4af1f9e36",
    "processingStart": "2021_07_06T21_50_48",
    "destinationDir": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool/tmprb1se376",
    "workflowDir": "tmprb1se376",
    "calSpl": "uid://evla/calibration/c78ccfd6-fe4e-43c6-a5c5-70e5bcfde16b",
    "staging_area": "/lustre/aoc/cluster/pipeline/docker/workspaces/staging",
    "storage_area": "/lustre/aoc/cluster/pipeline/docker/workspaces/storage",
}

image_collector = ImageCollector(parameters=parameters)


class TestImageCollector:
    @patch("builtins.open")
    def test_collect_image_metadata(self, mock_open):
        aux = image_collector.collect_image_metadata()
        assert mock_open.call_count == 1
        assert isinstance(aux, AbstractTextFile)

    @patch("subprocess.run")
    def test_collect_image_products(self, mock_run):
        image_collector.collect_image_products()
        assert mock_run.call_count == 1

    def test_create_artifacts_name(self):
        expected_name = "pipeline_artifacts_" + parameters["processingStart"]

        name = image_collector.create_artifacts_name()
        assert name == expected_name
